@@ -1,5 +1,5 @@
 # LIFT Integration-Functional Testing - A meta test framework
-# Copyright © 2014-2015 Arkena S.A and Nicolas Delvaux
+# Copyright © 2014-2021 Cognacq-Jay Image and Nicolas Delvaux
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -38,8 +38,8 @@ def ordered_load(stream):
         return OrderedDict(loader.construct_pairs(node))
 
     OrderedSafeLoader.add_constructor(
-        yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG,
-        construct_mapping)
+        yaml.resolver.BaseResolver.DEFAULT_MAPPING_TAG, construct_mapping
+    )
     return yaml.load(stream, OrderedSafeLoader)
 
 
@@ -52,22 +52,22 @@ def string_to_remote(string):
     Note that the PASSWORD field (along with the ':' separator) is optional.
     Return None if the input is not valid.
     """
-    if '=' not in string:
+    if "=" not in string:
         return None
-    name, rstring = string.split('=', 1)
-    if not name or '@' not in rstring:
+    name, rstring = string.split("=", 1)
+    if not name or "@" not in rstring:
         return None
     remote = {}
-    lstring, remote['host'] = rstring.rsplit('@', 1)
-    if not lstring or not remote['host']:
+    lstring, remote["host"] = rstring.rsplit("@", 1)
+    if not lstring or not remote["host"]:
         return None
 
-    if ':' in lstring:
-        remote['username'], remote['password'] = lstring.split(':', 1)
+    if ":" in lstring:
+        remote["username"], remote["password"] = lstring.split(":", 1)
     else:
-        remote['username'] = lstring
+        remote["username"] = lstring
 
-    if not remote['username']:
+    if not remote["username"]:
         return None
 
     return name, remote
@@ -86,14 +86,12 @@ def remote_to_string(remote):
 
     Return None if the input is not valid.
     """
-    if 'host' not in remote or 'username' not in remote:
+    if "host" not in remote or "username" not in remote:
         return None
-    if 'password' in remote:
-        return '%s:%s@%s' % (remote['username'],
-                             remote['password'],
-                             remote['host'])
-    else:
-        return '%s@%s' % (remote['username'], remote['host'])
+    if "password" in remote:
+        return f"{remote['username']}:{remote['password']}@{remote['host']}"
+
+    return f"{remote['username']}@{remote['host']}"
 
 
 def load_upper_inheritance(directory_path, preset_remotes):
@@ -110,29 +108,29 @@ def load_upper_inheritance(directory_path, preset_remotes):
     browsed = []
 
     directory = os.path.realpath(directory_path)
-    parent_directory = os.path.realpath(os.path.join(directory, '..'))
+    parent_directory = os.path.realpath(os.path.join(directory, ".."))
     while directory != parent_directory:  # not in root dir
-        upper_file = os.path.join(parent_directory, 'lift.yaml')
+        upper_file = os.path.join(parent_directory, "lift.yaml")
         if not os.path.isfile(upper_file):
             break
         browsed.insert(0, upper_file)
-        parent_directory = os.path.realpath(os.path.join(parent_directory, '..'))
+        parent_directory = os.path.realpath(os.path.join(parent_directory, ".."))
 
     # Load configuration from top to bottom
     for lift_file in browsed:
         try:
-            _, remotes, environment = load_config_file(lift_file,
-                                                       remotes,
-                                                       environment,
-                                                       preset_remotes)
+            _, remotes, environment = load_config_file(
+                lift_file, remotes, environment, preset_remotes
+            )
         except InvalidDescriptionFile as e:
-            sys.exit('%s is not a valid description file: %s' % (lift_file, e))
+            sys.exit(f"{lift_file} is not a valid description file: {e}")
 
     return remotes, environment
 
 
-def load_config_file(yaml_path, remotes, environment, preset_remotes,
-                     remotes_in_env=False):
+def load_config_file(
+    yaml_path, remotes, environment, preset_remotes, remotes_in_env=False
+):
     """Load a test-suite description file
 
     Parsed remotes and environment are merged with the provided parameters
@@ -151,69 +149,74 @@ def load_config_file(yaml_path, remotes, environment, preset_remotes,
 
     tests = []  # list of all tests
     # load settings
-    if 'settings' in conf:
-        for item in conf['settings']:
-            match = re.match('^define ([a-zA-Z0-9_\-\.]+)$', item)
+    if "settings" in conf:
+        for item in conf["settings"]:
+            match = re.match(r"^define ([a-zA-Z0-9_\-\.]+)$", item)
             if match:
                 name = match.group(1)
-                if name in ('test', 'define', 'complex', 'settings'):
-                    raise InvalidDescriptionFile('Hosts definition: "%s" '
-                                                 'is a reserved word' % name)
+                if name in ("test", "define", "complex", "settings"):
+                    raise InvalidDescriptionFile(
+                        f'Hosts definition: "{name}" is a reserved word'
+                    )
 
-                remotes[name] = conf['settings'][item]
+                remotes[name] = conf["settings"][item]
                 # Does the host definition contain all needed fields?
-                if not remotes[name].get('host', None):
-                    raise InvalidDescriptionFile('Missing host in "%s" definition'
-                                                 % name)
-                if not remotes[name].get('username', None):
-                    raise InvalidDescriptionFile('Missing username in "%s" definition'
-                                                 % name)
+                if not remotes[name].get("host", None):
+                    raise InvalidDescriptionFile(f'Missing host in "{name}" definition')
+                if not remotes[name].get("username", None):
+                    raise InvalidDescriptionFile(
+                        f'Missing username in "{name}" definition'
+                    )
                 # 'password' is optional, do not look for it
 
-            elif item == 'environment':
-                environment.update(conf['settings']['environment'])
+            elif item == "environment":
+                environment.update(conf["settings"]["environment"])
             else:
-                raise InvalidDescriptionFile('Unknown section in settings: %s'
-                                             % item)
+                raise InvalidDescriptionFile(f"Unknown section in settings: {item}")
 
     remotes.update(preset_remotes)  # if a preset remote was overridden
 
     for section in conf:
-        if section == 'settings':
+        if section == "settings":
             # Already handled
             continue
 
         # local test
-        match = re.match('^test ([a-zA-Z0-9_\-\.]+)$', section)
+        match = re.match(r"^test ([a-zA-Z0-9_\-\.]+)$", section)
         if match:
             # validate items
             for item in conf[section]:
-                if item not in ('command', 'return code', 'timeout', 'environment'):
-                    raise InvalidDescriptionFile('Unknown section in "%s": %s'
-                                                 % (section, item))
+                if item not in ("command", "return code", "timeout", "environment"):
+                    raise InvalidDescriptionFile(
+                        f'Unknown section in "{section}": {item}'
+                    )
 
             test_name = match.group(1)
             for test in tests:
                 if test.name == test_name:
-                    raise InvalidDescriptionFile('Duplicated test: %s' % test_name)
+                    raise InvalidDescriptionFile(f"Duplicated test: {test_name}")
 
-            if 'command' not in conf[section]:
-                raise InvalidDescriptionFile('No command defined for "%s".' % section)
+            if "command" not in conf[section]:
+                raise InvalidDescriptionFile(f'No command defined for "{section}".')
 
             # Create the test object
-            test = LocalTest(test_name,
-                             conf[section]['command'],
-                             directory=os.path.dirname(yaml_path),
-                             expected_return_code=conf[section].get('return code', 0),
-                             timeout=conf[section].get('timeout', 0),
-                             environment=environment.copy())
+            test = LocalTest(
+                test_name,
+                conf[section]["command"],
+                directory=os.path.dirname(yaml_path),
+                expected_return_code=conf[section].get("return code", 0),
+                timeout=conf[section].get("timeout", 0),
+                environment=environment.copy(),
+            )
             # Set the test environment
-            test.environment.update(conf[section].get('environment', {}))
+            test.environment.update(conf[section].get("environment", {}))
 
             if remotes_in_env:
                 remotes_env = {}
                 for remote in remotes:
-                    remotes_env['LIFT_REMOTE_%s' % remote] = remote_to_string(remotes[remote])
+                    remotes_env[f"LIFT_REMOTE_{remote}"] = remote_to_string(
+                        remotes[remote]
+                    )
                 test.environment.update(remotes_env)
 
             # Add it to the queue
@@ -221,43 +224,54 @@ def load_config_file(yaml_path, remotes, environment, preset_remotes,
             continue
 
         # Remote test
-        match = re.match('^([a-zA-Z0-9_\-\.]+) test ([a-zA-Z0-9_\-\.]+)$', section)
+        match = re.match(r"^([a-zA-Z0-9_\-\.]+) test ([a-zA-Z0-9_\-\.]+)$", section)
         if match:
 
             remote = match.group(1)
             if remote not in remotes:
-                raise InvalidDescriptionFile('Unknown remote: %s' % remote)
+                raise InvalidDescriptionFile(f"Unknown remote: {remote}")
 
             # validate items
             for item in conf[section]:
-                if item not in ('command', 'return code', 'timeout', 'resources', 'environment'):
-                    raise InvalidDescriptionFile('Unknown section in %s: %s'
-                                                 % (section, item))
+                if item not in (
+                    "command",
+                    "return code",
+                    "timeout",
+                    "resources",
+                    "environment",
+                ):
+                    raise InvalidDescriptionFile(
+                        f"Unknown section in {section}: {item}"
+                    )
 
             test_name = match.group(2)
             for test in tests:
                 if test.name == test_name:
-                    raise InvalidDescriptionFile('Duplicated test: %s' % test_name)
+                    raise InvalidDescriptionFile(f"Duplicated test: {test_name}")
 
-            if 'command' not in conf[section]:
-                raise InvalidDescriptionFile('No command defined for "%s".' % section)
+            if "command" not in conf[section]:
+                raise InvalidDescriptionFile(f'No command defined for "{section}".')
 
             # Create the test object
-            test = RemoteTest(test_name,
-                              conf[section]['command'],
-                              remotes[remote],
-                              resources=conf[section].get('resources', []),
-                              directory=os.path.dirname(yaml_path),
-                              expected_return_code=conf[section].get('return code', 0),
-                              timeout=conf[section].get('timeout', 0),
-                              environment=environment.copy())
+            test = RemoteTest(
+                test_name,
+                conf[section]["command"],
+                remotes[remote],
+                resources=conf[section].get("resources", []),
+                directory=os.path.dirname(yaml_path),
+                expected_return_code=conf[section].get("return code", 0),
+                timeout=conf[section].get("timeout", 0),
+                environment=environment.copy(),
+            )
             # Set the test environment
-            test.environment.update(conf[section].get('environment', {}))
+            test.environment.update(conf[section].get("environment", {}))
 
             if remotes_in_env:
                 remotes_env = {}
                 for remote in remotes:
-                    remotes_env['LIFT_REMOTE_%s' % remote] = remote_to_string(remotes[remote])
+                    remotes_env[f"LIFT_REMOTE_{remote}"] = remote_to_string(
+                        remotes[remote]
+                    )
                 test.environment.update(remotes_env)
 
             # Add it to the queue
@@ -265,6 +279,6 @@ def load_config_file(yaml_path, remotes, environment, preset_remotes,
             continue
 
         else:
-            raise InvalidDescriptionFile('Unknown section: %s' % section)
+            raise InvalidDescriptionFile(f"Unknown section: {section}")
 
     return tests, remotes, environment
